@@ -5,6 +5,7 @@ from typing import Union, Optional, Callable, DefaultDict, List, Dict, TypeVar,
 import zmq
 from pydantic import ValidationError, BaseModel
 
+from openmodule.config import settings
 from openmodule.models.base import ZMQMessage
 from openmodule.utils.schema import Schema
 
@@ -71,6 +72,16 @@ class MessageDispatcher:
             except ValueError:
                 pass
 
+    def _is_test_handler(self, handler):
+        """
+        this breaks separation a bit by including test specific code in the main module
+        but it improves developer usability drastically
+        """
+        if settings.TESTING and "Mock" in str(handler):
+            return True
+        else:
+            return False
+
     def register_handler(self, topic: Union[bytes, str],
                          message_class: Type[ZMQMessageSub],
                          handler: Callable[[ZMQMessageSub], None], *,
@@ -100,7 +111,7 @@ class MessageDispatcher:
         listener = Listener(message_class, filter, handler)
         self.listeners[topic].append(listener)
 
-        if register_schema:
+        if register_schema and not self._is_test_handler(handler):
             Schema.save_message(topic, message_class, handler, filter)
 
         return listener
