@@ -1,7 +1,7 @@
 from typing import Optional, Dict, Any
 from uuid import UUID
 
-from openmodule.models.base import ZMQMessage
+from openmodule.models.base import ZMQMessage, OpenModuleModel
 
 
 class RPCRequest(ZMQMessage):
@@ -13,3 +13,10 @@ class RPCRequest(ZMQMessage):
 class RPCResponse(ZMQMessage):
     rpc_id: Optional[UUID]
     response: Any
+
+
+class RPCResult(OpenModuleModel):
+    rpc_id: UUID
+    status: str = "error"
+    error: Optional[str]
+    response: Any
