@@ -9,6 +9,7 @@ from unittest import TestCase
 from openmodule.core import init_openmodule, shutdown_openmodule
 from openmodule.models.base import Direction
 from openmodule.models.presence import PresenceBaseMessage
+from openmodule.models.vehicle import MakeModel
 from openmodule.utils.presence import PresenceListener
 from openmodule_test.eventlistener import MockEvent
 from openmodule_test.presence import PresenceSimulator
@@ -110,6 +111,17 @@ class PresenceTest(BasePresenceTest):
         self.on_change.wait_for_call()
         self.assertEqual("GARIVO2", self.presence.present_vehicles["gate_in"].lpr.id)
 
+    def test_make_model_change(self):
+        vehicle_0 = self.presence_sim.vehicle().lpr("A", "GARIVO1")
+        self.presence_sim.enter(vehicle_0)
+        self.on_enter.wait_for_call()
+        self.assertEqual("GARIVO1", self.presence.present_vehicles["gate_in"].lpr.id)
+
+        vehicle_0.set_make_model(MakeModel(make="TESLA", make_confidence=0.7, model="UNKNOWN", model_confidence=-1.0))
+        self.presence_sim.change(vehicle_0)
+        self.on_change.wait_for_call()
+        self.assertEqual("TESLA", self.presence.present_vehicles["gate_in"].make_model.make)
+
     def test_normal(self):
         self.presence_sim.enter(self.presence_sim.vehicle().lpr("A", "G ARIVO1"))
         self.on_enter.wait_for_call()
@@ -177,7 +189,7 @@ class GateFilterTest(BasePresenceTest):
         self.on_enter.wait_for_call()
 
         self.assertIn("gate_out", self.presence.present_vehicles.keys())
-        with self.assertRaises(AssertionError):
+        with self.assertRaises(TimeoutError):
             self.on_enter2.wait_for_call()
 
         self.assertEqual({}, self.presence2.present_vehicles)
